Index: uspace/lib/c/arch/amd64/src/entry.S
===================================================================
--- uspace/lib/c/arch/amd64/src/entry.S	(revision ae7d03c05f24b857bbbdbcf3dafbf8ecc6c286ab)
+++ uspace/lib/c/arch/amd64/src/entry.S	(revision 38d8849c5dae9664aadfb5dfe635e66fd4bcb908)
@@ -29,5 +29,5 @@
 #include <abi/asmtool.h>
 
-.section .init, "ax"
+.text
 
 .org 0
@@ -46,4 +46,4 @@
 
 	# %rdi was deliberately chosen as the first argument is also in %rdi
-	# Pass PCB pointer to __libc_main (no operation)
-	call __libc_main
+	# Pass PCB pointer to __c_start (no operation)
+	call __c_start
